//
// NEW-MENU.CPP - Create a menu from scratch
//

#include <owl\applicat.h>
#include <owl\framewin.h>
#include <owl\menu.h>

#define CM_FILENEW	102
#define CM_FILEOPEN 103
#define CM_FILESAVE 104

// Class for the application
class TApp : public TApplication
{
public:
	TApp(): TApplication() {}
	void InitMainWindow();
};

// Class for the main window
class TWndw : public TFrameWindow
{
public:
	TWndw(TWindow *parent, const char far *title);

protected:
	TMenu *menu;
	TMenu *subMenu;

	void SetupWindow();
	void CleanupWindow();

	void CmFileNew();
	void CmFileOpen();
	void CmFileSave();

	DECLARE_RESPONSE_TABLE(TWndw);
};

DEFINE_RESPONSE_TABLE1(TWndw, TFrameWindow)
	EV_COMMAND(CM_FILENEW,  CmFileNew),
	EV_COMMAND(CM_FILEOPEN, CmFileOpen),
	EV_COMMAND(CM_FILESAVE, CmFileSave),
END_RESPONSE_TABLE;

//
// TWndw::TWndw()
//
TWndw::TWndw(TWindow *parent, const char far *title):
		TFrameWindow(parent, title)
{
	// Set the window's position and size
	Attr.X = 50;
	Attr.Y = 50;
	Attr.W = GetSystemMetrics(SM_CXSCREEN) / 1.5;
	Attr.H = GetSystemMetrics(SM_CYSCREEN) / 1.5;
}

//
// TWndw::SetupWindow()
//
void TWndw::SetupWindow()
{
  BOOL result;
	// create an empty menu
	menu = new TMenu();

	// initialize the sub menu pointer
	subMenu = NULL;

	// create a new popup window
	subMenu = new TPopupMenu();

	// Add file to the new popup menu
	subMenu->AppendMenu(MF_STRING, CM_FILENEW, "&New");
	subMenu->AppendMenu(MF_STRING, CM_FILEOPEN, "&Open");
	subMenu->AppendMenu(MF_STRING, CM_FILESAVE, "&Save");

	// Add the new menu to the window's menu bar.
	menu->AppendMenu(MF_POPUP, (UINT)(HMENU) *subMenu, "&File");

	// GetApplication()->GetMainWindow()->SetMenu( (HMENU)menu );
	SetMenu( (HMENU)*menu );
	// Draw the menu bar
	DrawMenuBar();
}

//
// TWndw::CleanupWindow()
//
void TWndw::CleanupWindow()
{
	if (menu)		delete menu;
	if (subMenu) 	delete subMenu;
}

//
// TWndw::CmFileNew()
//
void TWndw::CmFileNew()
{
	MessageBox("CM_FILENEW received!", "Message", MB_OK);
}

//
// TWndw::CmFileOpen()
//
void TWndw::CmFileOpen()
{
	MessageBox("CM_FILEOPEN received!", "Message", MB_OK);
}

//
// TWndw::CmFileSave()
//
void TWndw::CmFileSave()
{
	MessageBox("CM_FILESAVE received!", "Message", MB_OK);
}

//
// TApp::InitMainWindow()
//
void TApp::InitMainWindow()
{
	TFrameWindow *wndw = new TWndw(0, "Menu Application");
	SetMainWindow(wndw);
}

//
// OwlMain()
//
int OwlMain(int, char*[])
{
	return TApp().Run();
}
